@@ -14,20 +14,17 @@ For more details on the format specification, visit:
 http://www6.appliedbiosystems.com/support/software_community/ABIF_File_Format.pdf
 
 """
+
 import datetime
 import struct
 import sys
-
 from os.path import basename
 
-from typing import List
-
 from Bio.Seq import Seq
 from Bio.SeqRecord import SeqRecord
 
 from .Interfaces import SequenceIterator
 
-
 # dictionary for determining which tags goes into SeqRecord annotation
 # each key is tag_name + tag_number
 # if a tag entry needs to be added, just add its key and its key
@@ -327,7 +324,7 @@ _HEADFMT = ">H4sI2H3I"
 # directory data structure
 _DIRFMT = ">4sI2H4I"
 
-__global_tag_listing: List[str] = []
+__global_tag_listing: list[str] = []
 for tag in _INSTRUMENT_SPECIFIC_TAGS.values():
     __global_tag_listing += tag.keys()
 
