@@ -9,10 +9,12 @@
 # TODO samtools 1.x has additional options over 0.x which
 # are missing from this wrapper
 
-
-from Bio.Application import _Option, _Argument, _Switch
-from Bio.Application import AbstractCommandline, _ArgumentList
+from Bio.Application import _Argument
+from Bio.Application import _ArgumentList
+from Bio.Application import _Option
 from Bio.Application import _StaticArgument
+from Bio.Application import _Switch
+from Bio.Application import AbstractCommandline
 
 
 class SamtoolsViewCommandline(AbstractCommandline):
